diff --git a/books/axiom.sty b/books/axiom.sty
index 4665455..6efebf5 100644
--- a/books/axiom.sty
+++ b/books/axiom.sty
@@ -327,11 +327,18 @@
 %%
 
 \newcommand{\sig}[3]{% e.g. \sig{thisfunc}{In}{Out}
-{\bf #1} : {\bf #2} $\rightarrow$ {\bf #3}%
+\newline{\bf #1} : {\bf #2} $\rightarrow$ {\bf #3}%
 \index{signatures!#1}}
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %%
+%% Combine {\bf foo}(\ref{foo}) into a single command since it used a lot
+
+\newcommand{\bfref}[1]{% e.g. \bfref{thisfunc}
+\mbox{{\bf #1}(\ref{#1})}}
+
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%%
 %% calls marks a call from this function to another
 %%
 
diff --git a/changelog b/changelog
index 373a895..760fae0 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,5 @@
+20140914 tpd src/axiom-website/patches.html 20140914.02.tpd.patch
+20140914 tpd books/axiom.sty add \sig and \bfref
 20140914 tpd src/axiom-website/patches.html 20140914.01.tpd.patch
 20140914 tpd books/bookvolbib add Kaltofen references
 20140912 tpd src/axiom-website/patches.html 20140912.01.tpd.patch
diff --git a/patch b/patch
index c4d3edc..9d004e3 100644
--- a/patch
+++ b/patch
@@ -1,3 +1,12 @@
-books/bookvolbib add Kaltofen references
+books/axiom.sty add \sig and \bfref
 
-Eric Kaltofen reference works added.
+     \sig{foo}{(String,Integer)}{Boolean} 
+will generate an Axiom-like signature line, e.g.
+     foo : (String,Integer) -> Boolean
+in the pdf
+
+     \bfref{foo} 
+generates an inline link to the function definition
+which is useful in explanations. e.g.
+     foo (4.3)
+where 'foo' is in bold font and 4.3 is a hyperlink.
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index e404902..8234f7f 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -4636,6 +4636,8 @@ src/input/groeb.input test case for groebner basis<br/>
 books/axiom.sty add the sig markup<br/>
 <a href="patches/20140914.01.tpd.patch">20140914.01.tpd.patch</a>
 books/bookvolbib add Kaltofen references<br/>
+<a href="patches/20140914.02.tpd.patch">20140914.02.tpd.patch</a>
+books/axiom.sty add \sig and \bfref<br/>
  </body>
 </html>
 
